# Streamlit Card select

This small streamlit component renders Material-UI Cards in a grid as a selection alternative.
The component will return the last clicked component.

## Install

```bash
pip install streamlit-card-select
```